function [Pi, L1, L2, H, M, N,C11,C12]=darobsv96(dsys)
% 
%This function compute the gains for recuded order Darouach observer with unknown inputs [1] 
% 
% Calling Sequence
% 
%    [Pi, L1, L2, H, M, N,C11,C12]=darobsv96(E,A,B,C,F,G)  
%     
% Parameters
% E, A, B,C:
% Continuos matrices of descriptor system. E singular
% F, G:
% Unknown input matrices of the descriptor system
% Pi, L1, L2, H, M, N:
% Gains matrices of the observer
% C11 and C12
% Auxiliar matrices for simulation, this can be obtained from qrrse transformation
% 
% 
% Description
% 
%   Given a Descriptor system in the form
%     dxEdt=A x(t) + B u(t) +F d (t)
%      y   =C x(t) + D u(t) +G d(t)
% if the conditions in [1] are satisfied, then exist a reduced  order observer
%    dzdt=Pi z(t) + L1 y1(t) + L2 y2(t) H u(t)
%    xe=Mz(t) + N y2(t)
%  xe is the  stiamted output, u is the input.
% and  y1(t)=C11 x(t) + d1(t)  y2(t)=C12 x(t)
% For more information consult the reference. Observability conditions are tested inside the function
%      
% Examples
% Descriptor System
% E=[1 0 0 0 ; 0 1 0 0; 0 0 1 0; 0 0 0 0];
% A=[-1 1 0 0 ; -1 0 0 1; 0 -1 -1 0; 0 0 0 1];
% B=[1 0 0 1]';
% C=[1 0 0 0; 0 0 1 1];
% 
% F=[-1 0 0 0]';
% G=[0 0]';
% % Observer Gains
% [Pi, L1, L2, H, M, N,C11,C12]=darobsv96(E,A,B,C,F,G);
% 
%   
% See also
%   darobsv95 puiobsv
% 
% Authors
% Francisco Ronay LÓPEZ ESTRADA
%D. THEILLIOL
%C. M. ASTORGA-ZARAGOZA
%J. C. PONSART
% 
% Bibliography
% [1] ﻿Darouach, M., M. Zasadzinski, M. H. (1996). Reduced Observer Design 
% for Descriptor System with Unknown Input. IEEE Transactions on Automatic Control, 41(I), 1068-1072. 
[E,A,B,C,F,G]=dsys2ss(dsys);
[Ee, Ae, Ae1, Be, Be1, Ce,Fe,Fe1,De]=qrrse(E,A,B,C,F,G);

    % sizes of matrices
    n=size(E,2);
    m=size(E,1);
    r=rank(E);
    k=size(B,2);
    p=size(C,1);
    q=size(G,2);
    q1=rank(De)
    t=m+p-r;
    p1=t-q1;
    %%%%%%%%%%/
    
    %%%%%Verifiying controllability conditions
    
    %%%%%%%%%%%%%%%%%%%%%%/
    
    
    K=eye(n-p1,p1);
    R=rand(n-p1,n)*10;
%   R=[0 1 0 0]
%    [U,Cs, V]=svd(De); % QR factorization  
% solving $UDV=\begin{bmatrix} Iq_1 &0\\ 0 &0\end{bmatrix}$
d=size(De,1); 
Iq=eye(rank(De),rank(De));
 I=zeros(d,d)
 I(1:size(Iq,2),1:size(Iq,2))=Iq;
if De==0
U=eye(d,d);
V=eye(1,d);
else
 U=sdpvar(d,d,'full');
 V=sdpvar(1,d,'full');
cons=[U>0];
 cons=[cons,(U*De*V-I)==0];
options = sdpsettings('verbose',1,'solver','bmibnb');
 solvesdp(cons,trace(U),options);
U=double(U);
V=double(V);

end
%   pause
    UC=U*Ce;
       FV=Fe*V;
   t1=rank(De);
   if rank(De)==0
    C11=[];
    C12=UC;
    F11=[];
    F12=FV;
%    
Delta=clean(inv(Ee'*Ee+C12'*C12)); % between Ec. 11 and 12
varphi=clean([eye(r,r)-Ee*Delta*Ee'; -C12*Delta*Ee']);%
Phi=Ae;

   else
   C11=UC(1:rank(De),:);
   C12=UC(size(UC,1)-p1+1:size(UC,1),:);
   F11=FV(1:rank(F),:);
   F12=FV(rank(F)+1:size(FV,1),:)       ;
   Delta=clean(inv(Ee'*Ee+C12'*C12)); % between Ec. 11 and 12
varphi=clean([eye(r,r)-Ee*Delta*Ee'; -C12*Delta*Ee']);%
Phi=Ae-F11*C11;

   end


  
%
aux= zeros(size(R,2),1);
auxb=eye(n-p1,n-p1);
aux(1:size(aux,2),1:size(aux,2))=auxb;
M=inv([R;C12])*aux ;% eq. 24
%

alpha=clean(eye(r,r)-F12*pinv(varphi*F12)*varphi); % eq. between 24 and 25
%alpha=Delta*inv([Ee;C12]'*[Ee;C12])
Gamma=clean(varphi*alpha*Phi*M);
Omega=clean(R*Delta*Ee'*alpha*Phi*M);
Z=rand(1,size(varphi,1))*10;%[0 0 3 3 0 3 ]
T=(R*Delta*Ee'+Z*varphi)*alpha;

aux=zeros(n,r);
Ip1=eye(p1,p1);
aux(n-p1+1:n,:)=Ip1;
N=inv([T*Ee;C12])*aux; % eq. 25
Pi=T*Phi*M; % eq. 17
L2=T*Phi*N; % eq. 18
H=T*Be;    % eq. 5c

if rank(F11)==0
    L1=0;
else
    L1=T*F11   ; %eq. 5d
end
% Theorem 1
%T*Phi-Pi*T*Ee==L2*C12
%T*F12==zeros(T*F12)
%[T*Ee;C12]*[M N]==[eye(n-p1,n-p1) zeros(p1,p1);zeros(n-p1,n-p1) eye(p1,p1)]

