function [nC,Co_mat,nR,Ro_mat,nI,Io_mat]=dobsv(E,A,C)
% This fuction compute the C,R,I-Observability of Descriptor Systems using direct approach 
% Calling Sequence
% 
%    nC=dobsv(E,A,C)
%    [nC,Co_mat]=dobsv(E,A,C)
%    [nC,Co_mat,nR,Ro_mat]=dobsv(E,A,C)
%    [nC,Co_mat,nR,Ro_mat,nI,Io_mat]=dobsv(E,A,C)
% 
%      
% Parameters
% nC:
% Rank of C-Observability Matrix
% C_mat:
% C--Observability Matrices
% nR:
% Rank of R-Observability matrix
% nC:
% R-Observability Matrix
% nI:
% Rank of I-Observability matrix
% C_mat:
% I-Observability matrix
% R_mat:
% R-Observability matrix
% E,A,C:
% E, A and C matrices of descriptor system (E singular)
% Examples
% 
%   % This fuction compute the C,R,I_Observability
%       
%   % For detailed information look into dobsv.sci in macros path
% 
% E=[1 0 0 0; 0 1 0 0; 0 0 0 0; 0 0 0 0] ;
% A=[-0.8775 0 0.526 -0.0274;
%     -5.8500  -0.5 0.1481 0.0026; 
%     0      0.5   -1     0.2;
%     0      2.6522  -0.274  -2];
% B=[ 0 0; -0.0856  0.01; 0 0; 0 1];
% C=[1 1 0 1; 0 0 1 1;0 0 1 0];
% % only rank of C- Observability matrix with direct approach
% 
% [nC]=dobsv(E,A,B);
% % Rank and matrices of C-Observability with direct aproach
% [nC,Co_mat]=dobsv (E,A,B,0);
% % all ranks and matrices with direct method approach
% [nC,Co_mat,nR,Ro_mat,nI,Io_mat]=dobsv(E,A,C)
% 
%   
% See also
%   FundMatrix dcontr  
% Author
% Francisco-Ronay López-Estrada (ronaystein@gmail.com)
% Bibliography
% [1] Lewis, F. L. (1985). Fundamental, reachability, and observability matrices for discrete descriptor systems. IEE Transactions on Automatic Control 30(5), 502–505.
% [2] Koumboulis, F. N. and Mertzios,(1999), B. G. on Kalman Controlability and Observability Criteria for Singular Systems Circuits Systems and Signals, 18, 269-290
% [3] Duan, G.-R. Gao, D. Y. and Ogden, R. W. (Eds.) Analysis and Desing of Descriptor Linear Systems Springer, 2010  

% $rank\begin{bmatrix}sE-A\\C \end{bmatrix}=n,\,\,\,\forall s\in\mathbb{C},\,\, s\, finite$
   Cslow=[E-A;C];
   nCs=rank(Cslow);
   % %(b) The fast subsystem  is C-observable if and only if
    %$rank\begin{bmatrix}E\\ C \end{bmatrix}=n$
    Cfast=[E;C];
    nCf=rank(Cfast);
    
%     Co_mat=sprintf('%c = %f\n','Slow subsystem',Cslow,'Fast Subsystem',Cfast)
       Co_mat.SlowS=Cslow;
       Co_mat.FastS=Cfast;
    
    
    %(c) The Descriptor system is C-Observable if and only if  the slow subsystem is C-Controlable and the fast subsytem is C-Observable
    if  nCs==nCf & nCs==size(E,1) 
           nC.Obsv='T';
         nC.Des='System is  C-Controllable';
         nC.Ranks=[nCs nCf];
    else
         nC.Obsv='F';
         nC.Des='System is not C-Controllable. Slow and Fast Subsytem Ranks are not equals';
         nC.Ranks=[nCs nCf];
            
        end



% R observability
Ro_mat=Cslow;
if nCs==size(E,1) ;
    nR.Obsv='T';
    nR.Rank=nCs;
else
         nR.Obsv='F';
    nR.Rank=nCs;
end


% I Observability

Io_mat=[E A; zeros(size(E,1),size(E,1)) E; zeros(size(C,1),size(C,2)) C];
if rank(Io_mat)==(size(E,1)+rank(E)) 
%     nI=sprintf ('%s = %f\i','System is I-observable',rank(Io_mat))
  nI.Iobsv='T'
  nI.rank=rank(Io_mat);
else
nI.Iobsv='F'
  nI.rank=rank(Io_mat);
end
