function [N,G1,L,H2,Bo1]=gosbank1(dsys,alpha,flag,solv)
% This function compute the gains for an bank of observers using a proportiona observer with unknown inputs. [1] 
% Calling Sequence
% 
%   [N,G1,L,H2,Bo1]=gosbank(dsys,alpha,flag)
%     
% Parameters
% Sys: Descriptor system matrices with  E, A, B, C, R:
% Continuos matrices of descriptor system. E singular
% alpha: % For the stabilize the observer in a stable LMI region (see [1])
% flag: flag='. ' for sensor faults and 'a' for actuator faults. By default is programed for sensor faults
% N, G1, L, H2: Gains matrices of the observer
% Bo1:  % Auxliar matrix for simulation. see "puiobsv"
% 
% 
% Description
% 
%   Given a Descriptor system in the form
%     dxEdt=A x(t) + B u(t) +R d (t)
%      y   =C x(t) + D u(t) 
%  This compute an bank of observers based in the following proportional observer  
%    
%    dz/dt= Nz(t) + Gu(t) + Ly(t)+Tide(t)
%       xe= z(t) + H2y(t)
%      dde/dt= Phi (y(t)-ye(t))  
%   
%  xe = stimated states
%   y(t)=output
%   ye(t)=stimated output
% de= stimated unknown input 
% Followign the methodology presented in [1]  
% Example for fault detection in actuators (AFD)
% 
%  u inputs (in)         outputs
%            __________   
%    -------| Process  |-------------
%    ------ |__________|------------
% 
%            __________
% in2-------| obsv1    |-------------
% in2------|__________|-------------
% inm------
% 
%            __________
% in1-------| Observer2|-------------
% in3-------|__________|-------------
% inm--------     
%            __________
% in1    ----| Observer3|-------------
% in2 -------|__________|-------------
% in(m-1)----
% 
%   
% Examples
% Descriptor System
% 
% E=[1 0 0 0; 0 1 0 0; 0 0 0 0; 0 0 0 0];
% A=[-0.75 1 0 0; -1 -0.85 0 0; 0 -1 -0.75 0; 0 0 0 -1];
% B=[1 10 ;1 0.5 ; 0 0  ;1 0 ];
% % is very important select a correct matrix C
% % that meets the observability condition
% C=[1 0 1 0; 0 1 0 1; 1 0 0 0]; 
% 
% R=[-1 0 0 0]';
% [dsys]=dsystem(E,A,B,C,R);
% % Observer Gains
% alpha=3;
% sensors='s'
% [N,G1,L,H2,Bo1]=gosbank(E,A,B,C,R,alpha,sensors)
% %subindex (:,:,j) incates for the 1,2,..j th observer
% 
%   
% See also
%   piuiobsv darobsv96  
% Author
% Francisco-Ronay López-Estrada (ronaystein@gmail.com)
% Bibliography
% [1] ﻿﻿Paul M. Frank, (1990). Fault Diagnosis in Dynamic Systems Using
% Analytical and Knowledge-based Redundancy A Survey and Some New Results. Automatica, Vol. 26, No. 3, pp. 459-474. 

[E,A,Bi,Ci,R]=dsys2ss(dsys);

outputs=nargout;
inputs=nargin;
if inputs==2
    alpha=5;
    flag='s';
    solv='lmilab'
elseif inputs==3
    flag=='s';
        solv='lmilab';

end

if flag=='s'
    no=size(Ci,1); % no=number of observers for IFD
    
elseif flag=='a'
    no=size(Bi,2); %no=number de observers for AFD
end    
    
%%    
 j=1;
 h=1;
%  N=list();G1=list();L=list();H2=list();Bo1=list();
for j=1:no
    
%% this part select the correct matrices for the DOS structure
%For sensor faults
if flag=='s'
clear C;
    for k=1:no
        
        if k==j 
    C(k,:)=Ci(k,:);
        end
  
      
    end
    if size(C,1)~=1
     C = C(find(sum(C',1)~=0),:) %% delete rows of zeros
    end
     B=Bi;
% For actuator faults    
elseif flag=='a'
%    pause
clear B;
    for k=1:no
        
        if k==j 
    B(:,k)=Bi(:,k);
        end
  
      
    end
    if size(B,2)~=1
        B=B';
        
    B= B(find(sum(B',1)~=0),:)';%B(find(:,sum(B')>0)) %% delete rows of zeros
    end
    C=Ci;
end    
%pause
%% This part compute the gains of the observer
dsys=dsystem(E,A,B,C,R);
[Na,G1a,La,H2a,Bo1a]=puiobsv(dsys,alpha,solv);
N(:,:,j)=Na;
G1(:,:,j)=G1a;
L(:,:,j)=La;
H2(:,:,j)=H2a;
Bo1(:,:,j)=Bo1a;
j=j+1;

end

