function [Eo, Aoi, Ao1i, Boi, B1i, Coi, Roi,Ro0i]=lpvqrrse(E,A,B,C,R)

%This function compute the QR restricted system equivalence of a descriptor system l (E, A,B,C) or with unknown input (E, A, B, C,F,G). 
% 
% 
% Calling Sequence
% 
%    [Ee, Ae, Ae1, Be, Be1, Ce]=qrrse(E,A,B,C)
%    [Ee, Ae, Ae1, Be, Be1, Ce,Fe,Fe1,P]=qrrse(E,A,B,C,F)
%    
%    
% Parameters
% E, A, B, C:
% Matrices of descriptor system, E singular and pair (E, A) not necessarily regular.
% F,G:
% Descriptor system matrices, when unknowed input are considered like in Darouach, (1995) [1]
% Ee, Ae, Ae1, Be, Be1, Ce:
% Matrices of the qr r.s.e system
% Fe, Fe1, De:
% Matrices of equivalent qr r.s.e system when unknown inputs are considered [2]
%
% 
% Description
% QR restricted system equivalence of descriptor systems, considering restriccions in [1] and [2], if there exist a P matrix such that
% PE=[E2 0]*
% PA=[Ae Ae1]*
% PB=[Be1 Be2]*
% Ce=[Ae C]*
% and if unknowed inputs are considered [2], then
% Fe=[Fe Fe1]
% De=[Fe G]
% * indicates the transpose. For more deatiled help, see the qrrse.sci file in macros path
%
% 
% Examples
% % Descriptor system
% E=[1 0 0 0; 0 1 0 0; 0 0 0 0; 0 0 0 0];
% A=[-0.8775 0 0.526 -0.0274;
%     -5.8500  -0.5 0.1481 0.0026; 
%     0      0.5   -1     0.2;
%     0      2.6522  -0.274  -2];
% B=[ 0 0; -0.0856  0.01; 0 0; 0 1];
% C=[1 1 0 1; 0 0 1 1;0 0 1 0];
% 
% 
% Compute the QR r.s.e of (E,A),
%  [Ee, Ae, Ae1, Be, Be1, Ce]=qrrse(E,A,B,C)
% % QR r.s.e of  hole descriptor system with unknown inputs
% F=[-1 0 0 0]';
% G=[0 0]';
% 
% [Ee, Ae, Ae1, Be, Be1, Ce,Fe,Fe1,De]=qrrse(E,A,B,C,F,G)
% 
% 
% See also
%   pencan FundMatrix  
% 
% 
% Authors
% Francisco Ronay LÓPEZ ESTRADA
%D. THEILLIOL
%C. M. ASTORGA-ZARAGOZA
%J. C. PONSART
% 
% 
% Bibliography
% [1] Darouach, M. and Boutayeb, (1995). Design of Observers for Descriptor Systems. IEE Transactions on Automatic Control. Vol. 40, pp. 1323-1327
% [2] Darouach, M. , M. Zasadzinski and M. Hayar, (1996). Reduced-order observer design for descriptor systems with unknown inputs.IEEE Transactions on Automatic Control. Vol 41, Num. 7, pp. 1068-1072

w=size(A,3);
n=size(A,1);

for j=1:w
     
 [Eo, Ao, Ao1, Bo, Bo1, Co, Ro,Ro0]=qrrse(E,A(:,:,j),B(:,:,j),C,R);
%Eei(:,:,j)=Ee;
 Aoi(:,:,j)=Ao; Ao1i(:,:,j)=Ao1;  B1i(:,:,j)=Bo1; %Boi(:,:,j)=Bo;
  Coi(:,:,j)=Co; %Roi(:,:,j)=Ro;
%%  Considering for the first UIO
  Boi(:,:,j)=Bo;
  Roi=Ro;
Ro0i=Ro0;

%   Foi(:,:,j)=[1;0.5];

  % Eq. 34 
%   H12(:,:,j)=[eye(n,n) zeros(n,1)]*pinv([Eo  Roi(:,:,j); Coi(:,:,j) zeros(size(Coi(:,:,j),1),size(Roi(:,:,j),2))]);
%   H1i(:,:,j)=H12(:,1:2,j);
%   H2i(:,:,j)=H12(:,3:6,j);
end






%Any real square matrix A may be decomposed as 
   %   $QR$
%   
%   Rectangular matrix
%
%More generally, we can factor a complex $m×n$ matrix $A$, with $m ≥ n$, as the product of an m×m unitary matrix $Q$ and an $m×n$ upper triangular matrix $R$. As the bottom $(m−n)$ rows of an $m×n$ upper triangular matrix consist entirely of zeroes, it is often useful to partition $R$, or both $R$ and $Q$.:
%
%   $ A = QR = Q \begin{bmatrix} R_1 \\ 0 \end{bmatrix} $
%$=\begin{bmatrix} Q_1, Q_2 \end{bmatrix} \begin{bmatrix} R_1 \\ 0 \end{bmatrix} = Q_1 R_1, $
%where $R_1$ is an $n×n$ upper triangular matrix, $Q_1$ is $ m×n$, $Q_2$ is $m×(m−n)$E, and $Q_1$ and $Q_2$ both have orthogonal columns.


     