function rho=lpvweig(theta,h,flag)
% h=number of models
% flag: Method
%This function generates wieighting function for a Polytopic Linear Parameter 
% Varying Descriptor System of two vertices 
% 
% Calling Sequence
% 
% [mus]=lpvweig2(theta)  
% Parameters
% Theta:
% Is the measured parameter varying. This could be an scalar or a vector.
% mus:
% It is the vector of weightings function. mus=[mu1 mu2 sum(mu)] ^T. sum(mu) =1 for all time
% Description
% 
%   Given a polytopic LPV Descriptor system in the form
%        M
% dxEdt= Σmu(theta)[A(theta) x(t) + B(theta) u(t) +R(theta) d (t)]
%        i=1
%      y   =C x(t) + D u(t) 
% 
% Where theta is the parameter varying and it is bounde by two vertices. 
% This funtion is very usefull when the parameter varyin is an state of the systems (see [1]).
% The function builds the weighting function  Σmu(theta) given the vertices and the measured parameters theta.
% 
% Examples
% % parameter varying
% theta=0.5;
% mus=lpvweig2(theta)
% 
% % given a vector of measured parameters
% % this it is very useful for simulation
% theta=rand (1,40);
% mus=lpvweig2(theta)
% 
% 
% % plotting
% figure(1);
% cla();
% t=1:size(mus,2);
% subplot(211)  
% plot(t,theta)
% legend('Parameter varying')
% subplot(212)
% plot(t,mus)
% legend('Weighting functions')
% 
% See also
%   lpvweig3 lpvweig4  
% 
% Authors
% Francisco Ronay LÓPEZ ESTRADA (ronaystein@gmail.com)
%D. THEILLIOL
%C. M. ASTORGA-ZARAGOZA
%J. C. PONSART 

% Bibliography
% ﻿[1] ﻿Theilliol, D., & Aberkane, S. (n.d.). Design of LPV observers with unmeasurable gain scheduling variable under sensor faults. IFAC World Congress 2011.
% [2] ﻿M., Hamdi., Rodrigues, M., Mechmeche, C., Theilliol, D., Braiek, N. B., & Tunisie, E. P. D. (2009). State Estimation for Polytopic LPV Descriptor Systems : Application to Fault Diagnosis. Convergence (pp. 438-443).  
    
if h==2
    
    rho=lpvweig2(theta,flag)';
elseif h==3
     rho=lpvweig3(theta,flag)';
end
    