function rho=lpvweig3(xr,flag)
% This function generates wieighting function for a Polytopic Linear Parameter Varying Descriptor System of three vertices 
% Calling Sequence
% 
%   [mus]=lpvweig3(xr)  
% Parameters
% Theta:
% Is the measured parameter varying. This could be an scalar or a vector.
% mus:
% It is the vector of weightings function. mus=[mu1 mu2 mu3 sum(mu)]. sum(mu) =1 for all time
% Description
% 
%   Given a polytopic LPV Descriptor system in the form
%        M
% dxEdt= Σmu(xr)[A(xr) x(t) + B(xr) u(t) +R(xr) d (t)]
%        i=1
%      y   =C x(t) + D u(t) 
% 
% Where xr is the parameter varying and it is bounde by three vertices. 
% This funtion is very usefull when the parameter varyin is an state of the systems (see [1]).
% The function builds the weighting function  Σmu(xr) given the vertices and the measured parameters xr.
% 
% Examples
% % parameter varying
% xr=0.5;
% mus=lpvweig3(xr)
% 
% % given a vector of measured parameters
% % this it is very useful for simulation
% xr=rand (1,40);
% mus=lpvweig3(xr)
% 
% 
% % plotting
% figure(1);
% clf();
% t=1:size(mus,2);
% subplot(211)  
% plot(t,xr)
% legend('Parameter varying')
% subplot(212)
% plot(t,mus)
% legend('Weighting functions')
% See also
%   piuiobsv darobsv96  
% Author
% Francisco-Ronay López-Estrada (ronaystein@gmail.com)
% Bibliography
% ﻿[1] Habib, H., Rodrigues, M., Mechmeche, C., & Benhadj, N. (2010). 
% Robust H ∞ Fault Diagnosis for Multi-Model Descriptor Systems : A. Control.
% [2] ﻿M., Hamdi., Rodrigues, M., Mechmeche, C., Theilliol, D., Braiek, N. B., & Tunisie, E. P. D. (2009). State Estimation for Polytopic LPV Descriptor Systems : 
% Application to Fault Diagnosis. Convergence (pp. 438-443).

switch flag
    
    case 1
if size(xr,1)==1 & size(xr,2)==1; 
% a=-0.5; c=2; b=5;
a=-0.5; c=0.8; b=1.8;
  mu(1)=exp(-a*((xr+b)/2)^2)   ;
  mu(2)=exp(-a*(xr/c)^2);
  mu(3)=exp(-a*((xr-b)/2)^2); 
  
    rho=mu./sum(mu);
%     rho=[mus'; sum(mus)];
  
elseif size(xr,1)>1 | size(xr,2)>1;
   
   if size(xr,1)>size(xr,2)
       n=size(xr,1);
   elseif size(xr,2)>size(xr,1)
       n=size(xr,2);
   end
    for j=1:n
    
  mu(1)=exp(-0.5*((xr(j)+5)/2)^2)   ;
  mu(2)=exp(-0.5*(xr(j)/2)^2);
  mu(3)=exp(-0.5*((xr(j)-5)/2)^2); 
  
        mus=mu./sum(mu);
 rho(:,j)=[mus'; sum(mus)];
        
    end
    
end
    
    case 2
        
   b=[0 0 0];
c=[0.2 1 0.5];
% a=[1 , 1 ,1];
for j=1:3
a=1/(2*sqrt(c(j)*2*pi));
mu(j)=a*exp(-(xr-b(j))^2/(2*c(j))) ;
end
% disp ('case2')
    rho=mu./sum(mu);
   
   
    
    case 3
     xr=(xr*pi)/180;
        rho(1)=xr^2/6;
rho(2)=(1+cos(xr))/6;
rho(3)=(5-xr^2-cos(xr))/6;

    case 4
        
  mu(1)=exp(-0.8*((xr+5)/2)^2)   ;
  mu(2)=exp(-0.8*(xr/2)^2);
  mu(3)=exp(-0.8*((xr-5)/2)^2); 
  
    rho=mu./sum(mu);
%     rho=[mus'; sum(mus)];
        
end