function musa=lpvweig4U(x,c1,a1,a2)
% This function generates wieighting function for a Polytopic Linear Parameter Varying Descriptor System of three vertices 
% Calling Sequence
% 
%   [mus]=lpvweig3(x)  
% Parameters
% x:
% Is the measured parameter varying. This could be an scalar or a vector.
% mus:
% It is the vector of weightings function. mus=[mu1 mu2 mu3 sum(mu)]. sum(mu) =1 for all time
% Description
% 
%   Given a polytopic LPV Descriptor system in the form
%        M
% dxEdt= Σmu(x)[A(x) x(t) + B(x) u(t) +R(x) d (t)]
%        i=1
%      y   =C x(t) + D u(t) 
% 
% Where x is the parameter varying and it is bounde by three vertices. 
% This funtion is very usefull when the parameter varyin is an state of the systems (see [1]).
% The function builds the weighting function  Σmu(x) given the vertices and the measured parameters x.
% 
% Examples
% % parameter varying
% x=0.5;
% mus=lpvweig3(x)
% 
% % given a vector of measured parameters
% % this it is very useful for simulation
% x=rand (1,40);
% mus=lpvweig3(x)
% 
% 
% % plotting
% figure(1);
% clf();
% t=1:size(mus,2);
% subplot(211)  
% plot(t,x)
% legend('Parameter varying')
% subplot(212)
% plot(t,mus)
% legend('Weighting functions')
% See also
%   piuiobsv darobsv96  
% Author
% Francisco-Ronay López-Estrada (ronaystein@gmail.com)
% Bibliography
% ﻿[1] Habib, H., Rodrigues, M., Mechmeche, C., & Benhadj, N. (2010). 
% Robust H ∞ Fault Diagnosis for Multi-Model Descriptor Systems : A. Control.
% [2] ﻿M., Hamdi., Rodrigues, M., Mechmeche, C., Theilliol, D., Braiek, N. B., & Tunisie, E. P. D. (2009). State Estimation for Polytopic LPV Descriptor Systems : 
% Application to Fault Diagnosis. Convergence (pp. 438-443).

if size(x,1)==1 & size(x,2)==1; 

  mu(1)=exp(-0.5*((x+c1)/a1)^2)   ;
  mu(2)=exp(-0.5*(x/a1)^2);
  mu(3)=exp(-0.5*((x-c1)/a1)^2); 
 mu(4)=exp(-0.5*((x+a1)/a2)^2)  ;
    mus=mu./sum(mu);
    musa=[mus'; sum(mus)];
  
elseif size(x,1)>1 | size(x,2)>1;
   
   if size(x,1)>size(x,2)
       n=size(x,1);
   elseif size(x,2)>size(x,1)
       n=size(x,2);
   end
    for j=1:n
    
  mu(1)=exp(-0.5*((x(j)+c1)/2)^2)   ;
  mu(2)=exp(-0.5*(x(j)/2)^a1);
  mu(3)=exp(-0.5*((x(j)-5)/a1)^2); 
  mu(4)=exp(-0.5*((x(j)+c1)/a2)^2); 
        mus=mu./sum(mu);
  musa(:,j)=[mus'; sum(mus)];
        
    end
    
    end