function  [Pi,L, H,M, F,Be1]=redobsv95(dsys)

% This function compute the gains for recuded order Darouach observer of 1995 [1] 
% Calling Sequence
% 
%    [Pi,L, H,M, F,B1]=redobsv95(E,A,B,C)
%   
%     
% Parameters
% E, A, B,C:
% Continuos matrices of descriptor system. E singular
% Pi, L, H, M, F:
% Gains matrices of reduced Darouach Observer
% B1:
% Auxliar matrix for simulation. It is results from the QR r.se transformation
% Description
% 
%   Given a Descriptor system in the form
%     dxEdt=Ax+Bu
%      y   =Cx+Du
% if the conditions in [1] are satisfied, then exist a full order observer
%    dzdt=Phi z(t) + L y(t) + H u(t)
%    xe=M u(t) + F y(t)
%  xe is the  stiamted output, u is the input.
% and  y(t)=[ -B1u(t)  y*(t) ] y*(t)=Cx(t)
% For more information consult the reference. Observability conditions are tested inside the function
%      
% Examples
% 
%    % Descriptor system
% E=[1 0 0 0 ; 0 1 0 0; 0 0 0 0; 0 0 0 0];
% A=[0 0 1 0 ; 1 0 0 0; -1 0 0 1; 0 1 1 1];
% B=[0 0 0 -1]';
% C=[0 1 0 0];
% % Observer Gains
% 
% dsys=dsystem(E,A,B,C)
% [Pi,L, H,M, F,B1]=redobsv95(dsys)
% 
%   
% See also
%   abcdcoeff dobsv  
% Author
% Francisco-Ronay López-Estrada (ronaystein@gmail.com)
% Bibliography
% [1] M. Darouach and M. Boutayeb, (1995). Design of Observer for Descriptor Form. IEEE Transactions on Automatic Control. Vol. 70, pp. 1323-1327   
    [E,A,B,C]=dsys2ss(dsys);
[Ee, Ae, Ae1, Be, Be1, Ce]=qrrse(E,A,B,C);  

%   
%pause
m=size(E,1); r=rank(Ee); k=size(B,2);
n=size(E,2);p=size(C,1);q=rank(Ce);

 % verify the controllability condition
    Rank=rank([E;Ce]);
    if Rank~=n
        error('The controllability condition is not achieved: rank([E;C]is not ""n"", the output is not observable. ') 
        return
   end
          

K=eye(n-q,q)
R=eye(n-q,n);
Delta=inv(Ee'*Ee+Ce'*Ce); %


aux=[eye(r,r)-Ee*Delta*Ee'; -Ce*Delta*Ee'  ];
Z=rand(k,size(aux,1))*10;
T=R*Delta*Ee'+Z*aux  ; % eq.  25
M=inv([R;Ce])*[eye(n-q,n-q); zeros(q,n-q)]; %eq. 31
F=inv([T*Ee;Ce])*[zeros(k,q);eye(q,q)]; % eq. 32
Gamma=R*Delta*Ee'*Ae*M;
Omega=[(eye(r,r)-Ee*Delta*Ee')*Ae*M;-Ce*Delta*Ee'*Ae*M];
Pi=Gamma+Z*Omega;
%Pi=T*Ae*M
L=T*Ae*F
H=T*Be;
